import Vue from 'vue';
import Router from 'vue-router';

Vue.use(Router);

/**
 * Note: 路由配置项
 *
 * hidden: true                   // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
 * alwaysShow: true               // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 *                                // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 *                                // 若你想不管路由下面的 children 声明的个数都显示你的根路由
 *                                // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * redirect: noRedirect           // 当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'             // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    noCache: true                // 如果设置为true，则不会被 <keep-alive> 缓存(默认 false)
    title: 'title'               // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'             // 设置该路由的图标，对应路径src/assets/icons/svg
    breadcrumb: false            // 如果设置为false，则不会在breadcrumb面包屑中显示
  }
 */

// 公共路由
export const constantRoutes = [
  {
    path: '',
    component: resolve => require(['@/views/index'], resolve),
    name: 'index',
    children: [
      {
        path: 'index33',
        component: resolve => require(['@/views/index33'], resolve),
        name: 'index33',
        meta: { title: '客户管理' }
      },
      {
        path: 'index4',
        component: resolve => require(['@/views/index4'], resolve),
        name: 'index4',
        meta: { title: '客户管理' }
      },
      {
        path: 'index5',
        component: resolve => require(['@/views/index5'], resolve),
        name: 'index5',
        meta: { title: '客户管理' }
      },
      {
        path: 'index6',
        component: resolve => require(['@/views/index6'], resolve),
        name: 'index6',
        meta: { title: '客户管理' }
      },
      {
        path: 'index7',
        component: resolve => require(['@/views/index7'], resolve),
        name: 'index7',
        meta: { title: '客户管理' }
      },
      {
        path: 'index8',
        component: resolve => require(['@/views/index8'], resolve),
        name: 'index8',
        meta: { title: '客户管理' }
      },
      {
        path: 'index9',
        component: resolve => require(['@/views/index9'], resolve),
        name: 'index9',
        meta: { title: '客户管理' }
      }
    ]
  },
  {
    path: '/login',
    component: resolve => require(['@/views/login'], resolve),
    name: 'login'
  }
  // {
  //   path: '/redirect',
  //   // component: Layout,
  //   hidden: true,
  //   children: [
  //     {
  //       path: '/redirect/:path(.*)',
  //       component: resolve => require(['@/views/redirect'], resolve)
  //     }
  //   ]
  // },
  // {
  //   path: '/login',
  //   component: resolve => require(['@/views/login'], resolve),
  //   hidden: true
  // },
  // {
  //   path: '/404',
  //   component: resolve => require(['@/views/error/404'], resolve),
  //   hidden: true
  // },
  // {
  //   path: '/401',
  //   component: resolve => require(['@/views/error/401'], resolve),
  //   hidden: true
  // },
  // {
  //   path: '',
  //   // component: Layout,
  //   redirect: 'index',
  //   children: [
  //     {
  //       path: 'index',
  //       component: resolve => require(['@/views/index1'], resolve),
  //       name: 'index',
  //       meta: { title: '客户管理', noCache: true, affix: true, icon: 'user' }
  //     }
  //   ]
  // },
  // {
  //   path: '',
  //   component: Layout,
  //   redirect: 'index',
  //   children: [
  //     {
  //       path: 'index',
  //       component: resolve => require(['@/views/index'], resolve),
  //       name: '首页',
  //       meta: { title: '首页', icon: 'dashboard', noCache: true, affix: true }
  //     }
  //   ]
  // }
];
export const asyncRouterMap = [
  // // {
  // //   path: '',
  // //   // component: Layout,
  // //   redirect: 'index1',
  // //   children: [
  // //     {
  // //       path: 'index1',
  // //       component: resolve => require(['@/views/index1'], resolve),
  // //       name: 'index1',
  // //       meta: { title: '客户管理', noCache: true, affix: true, icon: 'user' }
  // //     }
  // //   ]
  // // },
  // // {
  // //   path: '',
  // //   // component: Layout,
  // //   redirect: 'index2',
  // //   children: [
  // //     {
  // //       path: 'index2',
  // //       component: resolve => require(['@/views/index2'], resolve),
  // //       name: 'index2',
  // //       meta: {
  // //         title: '权益商品',
  // //         noCache: true,
  // //         affix: true,
  // //         icon: 'shopping'
  // //       }
  // //     }
  // //   ]
  // // },
  // // {
  // //   path: '',
  // //   // component: Layout,
  // //   redirect: 'index3',
  // //   children: [
  // //     {
  // //       path: 'index3',
  // //       component: resolve => require(['@/views/index3'], resolve),
  // //       name: 'index3',
  // //       meta: { title: '提现订单', noCache: true, affix: true, icon: 'list' }
  // //     }
  // //   ]
  // // },
  // // {
  // //   path: '/ums',
  // //   // component: Layout,
  // //   redirect: '/ums/admin',
  // //   name: 'ums',
  // //   meta: { title: '系统设置', noCache: true, affix: true, icon: 'system' },
  // //   children: [
  // //     {
  // //       path: 'admin',
  // //       name: 'admin',
  // //       component: () => import('@/views/ums/admin/index'),
  // //       meta: { title: '用户列表', icon: 'list' }
  // //     },
  // //     {
  // //       path: 'role',
  // //       name: 'role',
  // //       component: () => import('@/views/ums/role/index'),
  // //       meta: { title: '角色列表', icon: 'list' }
  // //     },
  // //     {
  // //       path: 'allocMenu',
  // //       name: 'allocMenu',
  // //       component: () => import('@/views/ums/role/allocMenu'),
  // //       meta: { title: '分配菜单' },
  // //       hidden: true
  // //     },
  // //     {
  // //       path: 'allocResource',
  // //       name: 'allocResource',
  // //       component: () => import('@/views/ums/role/allocResource'),
  // //       meta: { title: '分配资源' },
  // //       hidden: true
  // //     },
  // //     {
  // //       path: 'menu',
  // //       name: 'menu',
  // //       component: () => import('@/views/ums/menu/index'),
  // //       meta: { title: '菜单列表', icon: 'list' }
  // //     },
  // //     {
  // //       path: 'addMenu',
  // //       name: 'addMenu',
  // //       component: () => import('@/views/ums/menu/add'),
  // //       meta: { title: '添加菜单' },
  // //       hidden: true
  // //     },
  // //     {
  // //       path: 'updateMenu',
  // //       name: 'updateMenu',
  // //       component: () => import('@/views/ums/menu/update'),
  // //       meta: { title: '修改菜单' },
  // //       hidden: true
  // //     },
  // //     {
  // //       path: 'resource',
  // //       name: 'resource',
  // //       component: () => import('@/views/ums/resource/index'),
  // //       meta: { title: '资源列表', icon: 'list' }
  // //     },
  // //     {
  // //       path: 'resourceCategory',
  // //       name: 'resourceCategory',
  // //       component: () => import('@/views/ums/resource/categoryList'),
  // //       meta: { title: '资源分类' },
  // //       hidden: true
  // //     }
  // //   ]
  // // },
  // // {
  // //   path: '/user',
  // //   // component: Layout,
  // //   hidden: true,
  // //   redirect: 'noredirect',
  // //   children: [
  // //     {
  // //       path: 'profile',
  // //       component: resolve =>
  // //         require(['@/views/system/user/profile/index'], resolve),
  // //       name: 'Profile',
  // //       meta: { title: '个人中心', icon: 'user' }
  // //     }
  // //   ]
  // // },
  // // {
  // //   path: '/dict',
  // //   // component: Layout,
  // //   hidden: true,
  // //   children: [
  // //     {
  // //       path: 'type/data/:dictId(\\d+)',
  // //       component: resolve => require(['@/views/system/dict/data'], resolve),
  // //       name: 'Data',
  // //       meta: { title: '字典数据', icon: '' }
  // //     }
  // //   ]
  // // },
  // // {
  // //   path: '/job',
  // //   // component: Layout,
  // //   hidden: true,
  // //   children: [
  // //     {
  // //       path: 'log',
  // //       component: resolve => require(['@/views/monitor/job/log'], resolve),
  // //       name: 'JobLog',
  // //       meta: { title: '调度日志' }
  // //     }
  // //   ]
  // // },
  // // {
  // //   path: '/gen',
  // //   // component: Layout,
  // //   hidden: true,
  // //   children: [
  // //     {
  // //       path: 'edit/:tableId(\\d+)',
  // //       component: resolve => require(['@/views/tool/gen/editTable'], resolve),
  // //       name: 'GenEdit',
  // //       meta: { title: '修改生成配置' }
  // //     }
  //   ]
  // }
];

export default new Router({
  mode: 'history', // 去掉url中的#
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
});
